@@ -1,13 +1,27 @@
 {% set template_domain_import = "shared.domain"|compute_base_path(template.name) %}
 {% set template_infra_import = "shared.infra"|compute_base_path(template.name) %}
+{% if template_domain_import %}
 from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
 from {{ general.source_name }}.{{ template_domain_import }}.event.event_bus import EventBus
+{% else %}
+from {{ general.source_name }}.event.domain_event import DomainEvent
+from {{ general.source_name }}.event.event_bus import EventBus
+{% endif %}
+{% if template_infra_import %}
 from {{ general.source_name }}.{{ template_infra_import }}.event.domain_event_json_serializer import (
     DomainEventJsonSerializer,
 )
 from {{ general.source_name }}.{{ template_infra_import }}.event.rabbit_mq.rabbit_mq_connection import (
     RabbitMqConnection,
 )
+{% else %}
+from {{ general.source_name }}.event.domain_event_json_serializer import (
+    DomainEventJsonSerializer,
+)
+from {{ general.source_name }}.event.rabbit_mq.rabbit_mq_connection import (
+    RabbitMqConnection,
+)
+{% endif %}
 
 
 class RabbitMqEventBus(EventBus):
